@@ -28,7 +28,7 @@ $EXPORT_TAGS{constants} = [qw(CU_OK
                               CU_TRY_AGAIN)];
 push @EXPORT_OK, @{$EXPORT_TAGS{constants}};
 
-$VERSION = '1.22';
+$VERSION = '1.23';
 
 use Carp;
 use Net::DNS;
@@ -58,6 +58,9 @@ $Treat_Timeout_As_Fail = 0;
 # if it is true Mail::CheckUser treats mailbox full message
 # as failed checks
 $Treat_Full_As_Fail = 0;
+# if it is true Mail::CheckUser treats temporary (400's)
+# as failed checks
+$Treat_Grey_As_Fail = 0;
 # sender addr used in MAIL/RCPT check
 $Sender_Addr = 'check@user.com';
 # sender domain used in HELO SMTP command - if undef lets
@@ -98,6 +101,7 @@ $NXDOMAIN = {
 
   # ph
   "203.119.4.6"      => 1, # A
+  "45.79.222.138"    => 1, # A
 
   # pw
   "216.98.141.250"   => 1, # A
@@ -126,6 +130,7 @@ $NXDOMAIN = {
   # ws
   "216.35.187.246"   => 1, # A
   "mail.worldsite.ws" => 1, # MX
+  "mail.hope-mail.com" => 1, # MX
   "216.35.187.251"   => 1, # MX
 
 };
@@ -768,6 +773,12 @@ If it is true C<Mail::CheckUser> treats error "552 mailbox full"
 as an invalid email and sets CU_MAILBOX_FULL.
 By default it is false.
 
+=item $Mail::CheckUser::Treat_Grey_As_Fail
+
+If it is true C<Mail::CheckUser> treats all 400's errors
+as an invalid email and sets CU_TRY_AGAIN.
+By default it is false.
+
 =item $Mail::CheckUser::Net_DNS_Resolver
 
 Override with customized Net::DNS::Resolver object.
